@@ -3,7 +3,7 @@ package Pod::Trial::LinkImg;
 use warnings;
 use strict;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 # ------------------------------------------------------------------------------
 # ------------------------------------------------------------------------------
@@ -18,7 +18,7 @@ Pod::Trial::LinkImg - Test image display in pod docs.
 
 =head1 VERSION
 
-Version 0.003
+Version 0.004
 
 =head1 SYNOPSIS
 
@@ -42,7 +42,7 @@ in B<Bell System Technical Journal, Jul/Aug 1978, Vol. 57, No. 6, Part 2>. (Yes
 I have a copy and for the young folks, there was only one phone company back
 then.)
 
-My calander today says we are about to flip to 2009 and yet I find no graphics
+My calander has flipped to 2009 and yet I find no graphics
 displayed in any documentation as displayed at
 L<http://search.cpan.org>.
 
@@ -55,9 +55,30 @@ displayed at L<http://search.cpan.org>.
 
 This do-nothing module is to test this out.
 
-=head2 Idea
+=head2 Demonstration
 
-My idea is to have images display as follows:
+The following snippet would be nice. If you are formatting in html, then you
+get an image, and if in text, then a note that there was an image. In pod, I
+do not believe that there is an C<if{}else{}> type clause, which would be nice,
+ie C<if(html){do this}else{do that}>. Hence the C<text> "block".
+
+    =begin html
+    
+    <br/ >Idea Figure<br /><IMG SRC="LinkImg/BrightIdea.png" /><br />
+    
+    =end html
+    
+    =begin text
+    
+    =over 4
+    
+    Image of 'Bright Idea', see C<BrightIdea.png>.
+    
+    =back
+    
+    =end text
+
+Below this line is the above code vvvvvv.
 
 =begin html
 
@@ -75,15 +96,32 @@ Image of 'Bright Idea', see C<BrightIdea.png>.
 
 =end text
 
-The real issue is what does the magic script behind L<http://search.cpan.org> do
-to display pod information. And what kind of link should be inserted to
-have it be found. Those are the questions to be determined.
+Above this line is the above code ^^^^^^.
 
-If it can be descerned what links are needed for
-L<http://search.cpan.org>,
-how would
-it fair for other distro type mechanisms such as C<ppm> in B<ActiveState>'s
-distribution and manual display.
+As you can see, neither shows up under L<http://search.cpan.org>.
+
+What will show? The following should provide a link which can be clicked
+to fetch the image.
+L<http://search.cpan.org/src/OTTO/Pod-Trial-LinkImg-0.004/lib/Pod/Trial/LinkImg/BrightIdea.png>
+
+So one could be reading the documentation and right click on a link and bring
+up an image say either in another tab or window.
+
+Presently I have found out that embedding images has been prohibited due
+to people XSS (cross-site-scripting) and inappropriate image display.
+
+Security is important, so prohibiting random html is good. However others have
+addressed this issue.
+
+Inappropriate images, can this not be censored appropriately in some manner.
+
+Presently the censorship is full - disallow all images. Can we not come up with
+something more appropriate than that?
+
+Other issues need also to be addressed, such as correct links for the html
+that is generated by such groups like ActiveState's ppm mechanism.
+
+First lets try to get good docs with images.
 
 =head1 AUTHOR
 
@@ -93,7 +131,7 @@ Otto Hirr, C<< <otto.hirr at olabinc.com> >>
 
 Please report any bugs or feature requests to C<bug-pod-trial-linkimg at
 rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=POD-Trial-LinkImg>. I will be
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Pod-Trial-LinkImg>. I will be
 notified, and then you'll automatically be notified of progress on your bug as I
 make changes.
 
